@@ -23,9 +23,13 @@ class DTSetting(Ui_DTSetting,QWidget):
 		
 		if self.app.isLoginEnable():
 			self.lineEdit_password.setText(self.app.password())
+			self.spinBox_iteration.setValue(self.app.iteration())
 		else:
 			self.lineEdit_password.hide()
 			self.label_password.hide()
+			self.spinBox_iteration.hide()
+			self.label_iteration.hide()
+			self.pushButton_iteration.hide()
 		
 		if self.app.DataList()!=[]:
 			self.lineEdit_data_dir.setText(self.app.DataDir())
@@ -55,7 +59,13 @@ class DTSetting(Ui_DTSetting,QWidget):
 
 		# scale
 		self.spinBox_scale.setValue(self.app.Scale())
-		self.comboBox_window_effect.setCurrentIndex(["Normal","Aero","Acrylic"].index(self.app.WindowEffect()))
+
+		# window effect
+		if sys.platform=="win32":
+			self.comboBox_window_effect.setCurrentIndex(["Normal","Aero","Acrylic"].index(self.app.WindowEffect()))
+		else:
+			self.label_window_effect.hide()
+			self.comboBox_window_effect.hide()
 		
 		# theme
 		self.comboBox_theme.addItems(self.app.ThemeList)
@@ -139,6 +149,7 @@ class DTSetting(Ui_DTSetting,QWidget):
 	
 		if self.app.isLoginEnable():
 			self.lineEdit_password.editingFinished.connect(self.PasswordSetting)
+			self.pushButton_iteration.clicked.connect(self.IterationSetting)
 		
 		self.pushButton_data_dir.clicked.connect(self.DataDirSetting)
 		
@@ -146,7 +157,10 @@ class DTSetting(Ui_DTSetting,QWidget):
 			self.pushButton_backup.clicked.connect(self.BackupSetting)
 		
 		self.pushButton_scale.clicked.connect(self.ScaleSetting)
-		self.comboBox_window_effect.currentIndexChanged.connect(self.WindowEffectSetting)
+		
+		if sys.platform=="win32":
+			self.comboBox_window_effect.currentIndexChanged.connect(self.WindowEffectSetting)
+		
 		self.comboBox_theme.currentIndexChanged.connect(self.ThemeSetting)
 		
 		self.pushButton_color.clicked.connect(self.ColorSetting)
@@ -179,6 +193,16 @@ class DTSetting(Ui_DTSetting,QWidget):
 		except:
 			DTFrame.DTMessageBox(self,"Warning","Error occur during password reseting!",DTIcon.Error())
 
+	def IterationSetting(self):
+		
+		try:
+			self.app.setIteration(self.spinBox_iteration.value())
+			self.app.setPassword(self.lineEdit_password.text())
+			self.Headquarter.saveAllEncryptData()
+			DTFrame.DTMessageBox(self,"Information","Iteration seted to \"%s\" successfully!"%self.app.iteration(),DTIcon.Information())
+		except:
+			DTFrame.DTMessageBox(self,"Warning","Error occur during password reseting!",DTIcon.Error())
+
 	def DataDirSetting(self):
 		dlg=QFileDialog(self)
 		data_dir=dlg.getExistingDirectory()
