@@ -13,6 +13,11 @@ class DTMainSession(DTFrame.DTMainWindow):
 		没有return: 这里要填啥
 	"""	
 
+	def closeEvent(self, event):
+		super().closeEvent(event)
+		if self.app.isQuitOnClickX() and sys.platform == "linux":
+			self.quit()
+
 	def __init__(self, app):
 		"""DTMainSession的构造函数
 
@@ -23,7 +28,7 @@ class DTMainSession(DTFrame.DTMainWindow):
 		super().__init__(app)
 
 		self.haveTanslation=hasattr(self.app,"translation")
-			
+	
 	
 	def initialize(self):
 		if self.haveTanslation==False and hasattr(self.app,"translation")==True:
@@ -67,10 +72,19 @@ class DTMainSession(DTFrame.DTMainWindow):
 		super().initializeSignal()
 		
 		self.actionExit.triggered.connect(self.quit)
-		if self.app.isQuitOnClickX():
-			self.TitleBar.btn_close.clicked.connect(self.quit)
-		else:
-			self.TitleBar.btn_close.clicked.connect(self.close)
+
+		if sys.platform == "win32":
+			if self.app.isQuitOnClickX():
+				self.TitleBar.btn_close.clicked.connect(self.quit)
+			else:
+				self.TitleBar.btn_close.clicked.connect(self.close)
+		elif sys.platform == "linux":
+			self.actionOpenWindow=QAction("Open Window")
+			self.actionOpenWindow.setIcon(IconFromCurrentTheme("window-restore.svg"))
+			self.actionOpenWindow.triggered.connect(self.show)
+		
+		if self.app.isLoginEnable():
+			self.actionSecure_Mode.triggered.connect(self.switchSecureMode)
 
 		self.actionSetting.triggered.connect(self.setting)
 		self.actionAbout.triggered.connect(self.about)
@@ -82,16 +96,16 @@ class DTMainSession(DTFrame.DTMainWindow):
 	
 	def initializeMenu(self):
 		"制定menu"
-
+		
 		if self.app.isBackupEnable():
-			self._MainMenu.addAction(self.actionBackup)
-			self._MainMenu.addSeparator()
+			self.addActionToMainMenu(self.actionBackup)
+			self.addSeparatorToMainMenu()
 		
 		################################################################
-
-		self._MainMenu.addAction(self.actionSetting)
-		self._MainMenu.addAction(self.actionAbout)
-		self._MainMenu.addSeparator()
+		
+		self.addActionToMainMenu(self.actionSetting)
+		self.addActionToMainMenu(self.actionAbout)
+		self.addSeparatorToMainMenu()
 		
 		################################################################
 		
@@ -104,57 +118,92 @@ class DTMainSession(DTFrame.DTMainWindow):
 		self.__menu_view.addAction(self.actionMaximize_Window)
 		self.addMenuToMainMenu(self.__menu_view)
 		
-		self._MainMenu.addAction(self.actionBoss_Key)
-		self._MainMenu.addAction(self.actionExit)
+		if self.app.isLoginEnable():
+			self.addActionToMainMenu(self.actionSecure_Mode)
+			self.SecureMode=True
+			self.actionSecure_Mode.setIcon(IconFromCurrentTheme("toggle-right.svg"))
+			self.actionSecure_Mode.setText(QCoreApplication.translate("Lobby", "Secure Mode - On"))
+
+		self.addActionToMainMenu(self.actionBoss_Key)
+		
+		self.addSeparatorToMainMenu()
+		if sys.platform == "linux":
+			self.addActionToMainMenu(self.actionOpenWindow)
+		self.addActionToMainMenu(self.actionExit)
 		
 	def refresh(self):
 		""""改变颜色后，可能有些依赖于app.color_list的颜色要更新，在这里添加对所有窗体的刷新操作"
 		"""
 		pass
 	
+	def switchSecureMode(self):
+		if self.SecureMode==False:
+			self.SecureMode=True
+			if self.isHidden():
+				for action in self._MainMenu.actions()[:-1]:
+					action.setVisible(False)
+			self.actionSecure_Mode.setIcon(IconFromCurrentTheme("toggle-right.svg"))
+			self.actionSecure_Mode.setText(QCoreApplication.translate("Lobby", "Secure Mode - On"))
+			DTFrame.DTMessageBox(self,"Information","Secure mode is on. Password will be needed when opening window from tray icon.",DTIcon.Happy())
+		else:
+			self.SecureMode=False
+			self.actionSecure_Mode.setIcon(IconFromCurrentTheme("toggle-left.svg"))
+			self.actionSecure_Mode.setText(QCoreApplication.translate("Lobby", "Secure Mode - Off"))
+			DTFrame.DTMessageBox(self,"Information","Secure mode is off. Password will not be needed when opening window from tray icon.",DTIcon.Happy())
+
 	def windowResurrection(self,reason):
 		"双击TrayIcon还原主窗体"
 		
 		from DTPySide import DTSession
 		# 必须在这里再调用一次，如果不写的话，下面会说name 'DTSession' is not defined。不知道为什么啊啊啊，明明都在DTPySide的__init__中导入过了呀？！难道又是同级包内互相调用的问题，还是__feature__的annotation暂时还有bug？
 
-		if reason==QSystemTrayIcon.DoubleClick:
+		if reason==QSystemTrayIcon.Trigger:
 			if self.isHidden():
 				# 有Login选项
-				if self.app.isLoginEnable():
+				if self.app.isLoginEnable() and self.SecureMode:
 
 					# 还未出现Login界面
 					if not hasattr(self,"ResurrectionDlg"):
-						self.ResurrectionDlg=DTSession.DTLoginSession(self.UserSetting().value("BasicInfo/Password"))
-
+						self.ResurrectionDlg=DTSession.DTLoginSession(self.UserSetting().value("BasicInfo/Password"), self.app.iteration())
+						
 						#成功登回
 						if self.ResurrectionDlg.exec_():
-							self.showNormal()
 							# 恢复self._MainMenu里的其他action
 							for action in self._MainMenu.actions()[:-1]:
 								action.setVisible(True)
+							if sys.platform=="linux":
+								self.actionOpenWindow.triggered.disconnect()
+								self.actionOpenWindow.triggered.connect(self.show)
+							self.show()
 						
 						del self.ResurrectionDlg
 					
 					# 已经有Login界面了
 					else:
+						self.ResurrectionDlg.activateWindow()
 						pass
 				
 				# 无Login选项
 				else:
-					self.showNormal()
-			
+					self.show()
+					self.activateWindow()
+
 			# 
 			else:
-				self.showNormal()
+				self.show()
+				self.activateWindow()
 	
 	def bossComing(self):
 		self.hide()
 		
-		if self.app.isLoginEnable():
+		if self.app.isLoginEnable() and self.SecureMode:
 			# Boss键后只显示退出键，self._MainMenu里的其他action隐藏掉
 			for action in self._MainMenu.actions()[:-1]:
-				action.setVisible(False)
+				if sys.platform=="linux" and action.text()=="Open Window":
+					self.actionOpenWindow.triggered.disconnect()
+					self.actionOpenWindow.triggered.connect(lambda:self.windowResurrection(QSystemTrayIcon.Trigger))
+				else:
+					action.setVisible(False)
 	
 	def loadData(self):
 		"""这里请用self.app.DataDir获取Data的路径
@@ -199,10 +248,10 @@ class DTMainSession(DTFrame.DTMainWindow):
 		elif not os.path.exists(backup_dst):
 			DTFrame.DTMessageBox(self,"Warning","Backup Dst %s does not exsit!"%backup_dst,DTIcon.Warning())
 		else:
-			new_folder_dst=os.path.join(backup_dst,WhatDayIsToday(1).toString("yyyyMMdd")).replace("/","\\")
+			new_folder_dst=os.path.join(backup_dst,WhatDayIsToday(1).toString("yyyyMMdd"))
 			self.backup_thread=BackUpThread(self, self.app.DataDir(), self.app.DataList())
 			self.backup_thread.finished.connect(self.backup_thread.deleteLater)
-			self.backup_thread.finished.connect(lambda:self.app.showMessage("Information", "Data backup completed.", DTIcon.Information(), clicked_slot=lambda:os.popen("explorer /select,\"%s\""%new_folder_dst)))
+			self.backup_thread.finished.connect(lambda:self.app.showMessage("Information", "Data backup completed.", DTIcon.Information(), clicked_slot=lambda: Open_Explorer(new_folder_dst, True)))
 			self.backup_thread.start()
 
 	def about(self):
