@@ -54,10 +54,10 @@ class DTStyleSheet(str):
 
 		QDialog {{
 			border: 2px solid {DEEPDARK};
-			border-radius: 1px;
+			border-radius: 2px;
 		}}
 
-		#DTMainWindow #statusBar{{
+		#DTMainWindowWin32 #statusBar, #DTMainWindowLinux #statusBar{{
 			background-color: {SOFTDARK};
 			font-family: "微软雅黑";
 			font-size: 9pt;
@@ -269,7 +269,9 @@ class DTStyleSheet(str):
 
 		QToolTip {{
 			background: {SOFTDARK};
-			color: {TEXT}
+			color: {TEXT};
+			font-family: {font_family};
+			font-size: 11pt;
 		}}
 
 
@@ -594,17 +596,9 @@ class DTStyleSheet(str):
 
 		/* DockWidget*/
 
-		QDockWidget, QDockWidget > QWidget /*not work*/
-		{{
-			border-color: {DEEPDARK}; /*qt bug*/
-			background: transparent;
+		QDockWidget > QWidget {{
+			border: transparent;
 		}}
-		QDockWidget::title {{
-			border-bottom: 1px solid {DEEPDARK};
-			text-align: left;
-			padding: 6px;
-		}}
-
 
 		/* GroupBox */
 
